@@ -19,19 +19,28 @@ use Exporter;
 @ISA = qw( Exporter );
 @EXPORT = qw ();
 
+## ----------------------------------------------------------------------
+## get command line options
+use vars qw( $opt_L $opt_P $opt_b $opt_c $opt_e $opt_f $opt_l $opt_m $opt_t $opt_1 $opt_x $opt_X);
+getopts( 'LPb:ce:f:l:mt:1xX:' );
+
 ## ----------------------------------------------------------------------
 ## import packages
 use DebianDoc_SGML::Format::Alias;
-use DebianDoc_SGML::Locale::Alias;
+if ( length( $opt_X ) )
+{
+# if "-X dir" is defined, use diras the Locale format data source.
+    require "$opt_X/Alias.pm";
+    DebianDoc_SGML::Locale::Alias->import();
+}
+else
+{
+    use DebianDoc_SGML::Locale::Alias;
+}
 use Getopt::Std;
 use POSIX qw( locale_h );
 use SGMLS::Output;
 
-## ----------------------------------------------------------------------
-## get command line options
-use vars qw( $opt_L $opt_P $opt_b $opt_c $opt_e $opt_f $opt_l $opt_m $opt_t $opt_1 $opt_x );
-getopts( 'LPb:ce:f:l:mt:1x' );
-
 ## ----------------------------------------------------------------------
 ## get format, map and locale
 use vars qw( $format $Format $Map );
@@ -57,7 +66,15 @@ use vars qw( $locale $Locale %locale );
     }
     my $locale_alias = $locale_aliases{$locale};
     $Locale = "DebianDoc_SGML/Locale/$locale_alias/$format_alias";
-    require $Locale;
+    if ( length( $opt_X ) )
+    {
+    # if "-X dir" is defined, use diras the Locale format data source.
+    	require "$opt_X/$locale_alias/$format_alias";
+    }
+    else
+    {
+    	require $Locale;
+    }
     $Locale =~ s|/|::|g;
     $Map = "DebianDoc_SGML/Map/$format_alias";
     require "$Map.pm";
@@ -648,7 +665,7 @@ sub start_taglist
     $is_footnote = 0;
     push( @list_type, $list_type );
     $list_type = "taglist";
-    push( @tags, @tag );
+    push( @tags, [ @tag ] );
     @tag = ();
     $indent_level++ if $indent_level;
     push_output( 'string' );
@@ -659,7 +676,7 @@ sub end_taglist
     $taglist =~ s/\s+$//;
     &{$Format."::"._output_taglist}( "$taglist\n", pop( @p_length ) );
     $indent_level-- if $indent_level > 1;
-    @tag = pop( @tags );
+    @tag = @{ pop( @tags ) };
     $is_footnote = pop( @is_footnote );
     $list_type = pop( @list_type );
     $was_compact = $is_compact;
