@@ -39,7 +39,7 @@ if ( $DebianDoc_SGML::Format::Driver::opt_c )
 {
     my $locale = $DebianDoc_SGML::Format::Driver::locale;
     $locale =~ s/[\.@].*//;
-    my $language_tag = lc( locale2language_tag( $locale ) );
+    my $language_tag = lc( locale2language_tag( $DebianDoc_SGML::Format::Driver::opt_l ) );
     $language_tag = 'en' if $language_tag eq undef;
     my $charset = ".$locale{ 'charset' }"
 	if length( $locale{ 'charset' } )
