@@ -165,8 +165,8 @@ sub _html_head
 {
     output( "<?xml version='1.0'?>\n" );
     output( "<!-- -*- DocBook -*- -->\n" );
-    output( "<!DOCTYPE book PUBLIC \"-//OASIS//DTD DocBook XML V4.2//EN\"\n" );
-    output( "    \"/usr/share/sgml/docbook/dtd/xml/4.2/docbookx.dtd\" [\n" );
+    output( "<!DOCTYPE book PUBLIC \"-//OASIS//DTD DocBook XML V4.4//EN\"\n" );
+    output( "    \"http://www.oasis-open.org/docbook/xml/4.4/docbookx.dtd\" [\n" );
 #    output( "<!ENTITY % sgml.features \"IGNORE\">\n" );
 #    output( "<!ENTITY % xml.features  \"INCLUDE\">\n" );
     if ( ! $DebianDoc_SGML::Format::Driver::opt_1 )
@@ -415,23 +415,28 @@ sub _output_appendix
 }
 sub _output_sect
 {
-    output( "</sect1>\n\n" );
+#    output( "</sect1>\n\n" );
+    output( "</sect>\n\n" );
 }
 sub _output_sect1
 {
-    output( "</sect2>\n\n" );
+#    output( "</sect2>\n\n" );
+    output( "</sect>\n\n" );
 }
 sub _output_sect2
 {
-    output( "</sect3>\n\n" );
+#    output( "</sect3>\n\n" );
+    output( "</sect>\n\n" );
 }
 sub _output_sect3
 {
-    output( "</sect4>\n\n" );
+#    output( "</sect4>\n\n" );
+    output( "</sect>\n\n" );
 }
 sub _output_sect4
 {
-    output( "</sect5>\n\n" );
+#    output( "</sect5>\n\n" );
+    output( "</sect>\n\n" );
 }
 sub _output_heading
 {
@@ -466,7 +471,8 @@ sub _output_heading
 	$idx =~ s/^s-//;
 	$idx =~ s/_/-/g;
 	$idx =~ s/ /-/g;
-	output( "<sect$xmlsectid id=\"$idx\">" );
+#	output( "<sect$xmlsectid id=\"$idx\">" );
+	output( "<sect id=\"$idx\">" );
 	if ( length( $_[0] ) )
 	{
             output( "<title>" );
@@ -496,7 +502,7 @@ sub _output_p
 sub _output_example
 {
     $_[0] =~ s/\s+$/\n/;
-    $_[0] =~ s/^\w*//; # remove white space only first line
+#    $_[0] =~ s/^\W*$//; # remove white space only first line
     output( "<screen>\n" );
     output( $_[0] );
     output( "</screen>" );
@@ -636,7 +642,7 @@ sub _output_qref
     $idx =~ s/^s-//;
     $idx =~ s/_/-/g;
     $idx =~ s/ /-/g;
-    output( "<link id=\"$idx\"></link>\n" );
+    output( "<link linkend=\"$idx\">$_[0]</link>\n" );
 }
 
 ## ----------------------------------------------------------------------
@@ -675,7 +681,7 @@ sub _output_email
 sub _output_ftpsite
 {
     my $url = URI->new( $_[0] );
-    output( "<ftpsite>$url</ftpsite>" );
+    output( "<ulink url=\"$url\">$url</ulink>" );
 }
 sub _output_ftppath
 {
