@@ -19,173 +19,231 @@ use Exporter;
 
 ## ----------------------------------------------------------------------
 ## locale alias definitions
+##
+## left side is the argument for -l option.
+## right side is the data directory name.
+##
 use vars qw( %locale_aliases );
 %locale_aliases = (
 
 		   'ca'				=> 'ca_ES.ISO8859-1',
 		   'ca_ES'			=> 'ca_ES.ISO8859-1',
 		   'ca_ES.ISO8859-1'		=> 'ca_ES.ISO8859-1',
-
 		   'ca_ES@euro'			=> 'ca_ES.ISO8859-15',
 		   'ca_ES.ISO8859-15'		=> 'ca_ES.ISO8859-15',
 		   'ca_ES.ISO8859-15@euro'	=> 'ca_ES.ISO8859-15',
+		   'ca.UTF-8'			=> 'ca_ES.UTF-8',
+		   'ca_ES.UTF-8'		=> 'ca_ES.UTF-8',
 
 		   'cs'				=> 'cs_CZ.ISO8859-2',
 		   'cs_CZ'			=> 'cs_CZ.ISO8859-2',
 		   'cs_CZ.ISO8859-2'		=> 'cs_CZ.ISO8859-2',
+		   'cs.UTF-8'			=> 'cs_CZ.UTF-8',
+		   'cs_CZ.UTF-8'		=> 'cs_CZ.UTF-8',
 
 		   'da'				=> 'da_DK.ISO8859-1',
 		   'da_DK'			=> 'da_DK.ISO8859-1',
 		   'da_DK.ISO8859-1'		=> 'da_DK.ISO8859-1',
+		   'da.UTF-8'			=> 'da_DK.UTF-8',
+		   'da_DK.UTF-8'		=> 'da_DK.UTF-8',
 
 		   'de'				=> 'de_DE.ISO8859-1',
 		   'de_DE'			=> 'de_DE.ISO8859-1',
 		   'de_DE.ISO8859-1'		=> 'de_DE.ISO8859-1',
-
 		   'de_DE@euro'			=> 'de_DE.ISO8859-15',
 		   'de_DE.ISO8859-15'		=> 'de_DE.ISO8859-15',
 		   'de_DE.ISO8859-15@euro'	=> 'de_DE.ISO8859-15',
+		   'de.UTF-8'			=> 'de_DE.UTF-8',
+		   'de_DE.UTF-8'		=> 'de_DE.UTF-8',
 
 		   'en'				=> 'en_US.ISO8859-1',
+		   'en_GB'			=> 'en_US.ISO8859-1',
+		   'en_GB.ISO8859-1'		=> 'en_US.ISO8859-1',
+		   'en_GB@euro'			=> 'en_US.ISO8859-15',
+		   'en_GB.ISO8859-15'		=> 'en_US.ISO8859-15',
+		   'en_GB.ISO8859-15@euro'	=> 'en_US.ISO8859-15',
+		   'en_GB.UTF-8'		=> 'en_US.UTF-8',
+
 		   'en_US'			=> 'en_US.ISO8859-1',
 		   'en_US.ISO8859-1'		=> 'en_US.ISO8859-1',
+		   'en_US@euro'			=> 'en_US.ISO8859-15',
+		   'en_US.ISO8859-15'		=> 'en_US.ISO8859-15',
+		   'en_US.ISO8859-15@euro'	=> 'en_US.ISO8859-15',
+		   'en.UTF-8'			=> 'en_US.UTF-8',
+		   'en_US.UTF-8'		=> 'en_US.UTF-8',
 
 		   'es'				=> 'es_ES.ISO8859-1',
 		   'es_ES'			=> 'es_ES.ISO8859-1',
 		   'es_ES.ISO8859-1'		=> 'es_ES.ISO8859-1',
-
 		   'es_ES@euro'			=> 'es_ES.ISO8859-15',
 		   'es_ES.ISO8859-15'           => 'es_ES.ISO8859-15',
 		   'es_ES.ISO8859-15@euro'	=> 'es_ES.ISO8859-15',
+		   'es.UTF-8'			=> 'es_ES.UTF-8',
+		   'es_ES.UTF-8'		=> 'es_ES.UTF-8',
 
 		   'eu'				=> 'eu_ES.ISO8859-1',
 		   'eu_ES'			=> 'eu_ES.ISO8859-1',
 		   'eu_ES.ISO8859-1'		=> 'eu_ES.ISO8859-1',
-
 		   'eu_ES@euro'			=> 'eu_ES.ISO8859-15',
 		   'eu_ES.ISO8859-15'		=> 'eu_ES.ISO8859-15',
 		   'eu_ES.ISO8859-15@euro'	=> 'eu_ES.ISO8859-15',
+		   'eu.UTF-8'			=> 'eu_ES.UTF-8',
+		   'eu_ES.UTF-8'		=> 'eu_ES.UTF-8',
 
 		   'eu_FR'			=> 'eu_FR.ISO8859-1',
 		   'eu_FR.ISO8859-1'		=> 'eu_FR.ISO8859-1',
-
 		   'eu_FR@euro'			=> 'eu_FR.ISO8859-15',
 		   'eu_FR.ISO8859-15'		=> 'eu_FR.ISO8859-15',
 		   'eu_FR.ISO8859-15@euro'	=> 'eu_FR.ISO8859-15',
+		   'eu_FR.UTF-8'		=> 'eu_FR.UTF-8',
 
 		   'fi'				=> 'fi_FI.ISO8859-1',
 		   'fi_FI'			=> 'fi_FI.ISO8859-1',
 		   'fi_FI.ISO8859-1'		=> 'fi_FI.ISO8859-1',
-
 		   'fi_FI@euro'			=> 'fi_FI.ISO8859-15',
 		   'fi_FI.ISO8859-15'		=> 'fi_FI.ISO8859-15',
 		   'fi_FI.ISO8859-15@euro'	=> 'fi_FI.ISO8859-15',
+		   'fi.UTF-8'			=> 'fi_FI.UTF-8',
+		   'fi_FI.UTF-8'		=> 'fi_FI.UTF-8',
 
 		   'fr'				=> 'fr_FR.ISO8859-1',
 		   'fr_FR'			=> 'fr_FR.ISO8859-1',
 		   'fr_FR.ISO8859-1'		=> 'fr_FR.ISO8859-1',
-
 		   'fr_FR@euro'			=> 'fr_FR.ISO8859-15',
 		   'fr_FR.ISO8859-15'		=> 'fr_FR.ISO8859-15',
 		   'fr_FR.ISO8859-15@euro'	=> 'fr_FR.ISO8859-15',
+		   'fr.UTF-8'			=> 'fr_FR.UTF-8',
+		   'fr_FR.UTF-8'		=> 'fr_FR.UTF-8',
 
 		   'gl'				=> 'gl_ES.ISO8859-1',
 		   'gl_ES'			=> 'gl_ES.ISO8859-1',
 		   'gl_ES.ISO8859-1'		=> 'gl_ES.ISO8859-1',
-
 		   'gl_ES@euro'			=> 'gl_ES.ISO8859-15',
 		   'gl_ES.ISO8859-15'		=> 'gl_ES.ISO8859-15',
 		   'gl_ES.ISO8859-15@euro'	=> 'gl_ES.ISO8859-15',
+		   'gl.UTF-8'			=> 'gl_ES.UTF-8',
+		   'gl_ES.UTF-8'		=> 'gl_ES.UTF-8',
 
 		   'hr'				=> 'hr_HR.ISO8859-2',
 		   'hr_HR'			=> 'hr_HR.ISO8859-2',
 		   'hr_HR.ISO8859-2'		=> 'hr_HR.ISO8859-2',
+		   'hr.UTF-8'			=> 'hr_HR.UTF-8',
+		   'hr_HR.UTF-8'		=> 'hr_HR.UTF-8',
 
 		   'it'				=> 'it_IT.ISO8859-1',
 		   'it_IT'			=> 'it_IT.ISO8859-1',
 		   'it_IT.ISO8859-1'		=> 'it_IT.ISO8859-1',
-
 		   'it_IT@euro'			=> 'it_IT.ISO8859-15',
 		   'it_IT.ISO8859-15'		=> 'it_IT.ISO8859-15',
 		   'it_IT.ISO8859-15@euro'	=> 'it_IT.ISO8859-15',
+		   'it.UTF-8'			=> 'it_IT.UTF-8',
+		   'it_IT.UTF-8'		=> 'it_IT.UTF-8',
 
 		   'ja'				=> 'ja_JP.eucJP',
 		   'ja_JP'			=> 'ja_JP.eucJP',
 		   'ja_JP.eucJP'		=> 'ja_JP.eucJP',
 		   'ja_JP.ujis'			=> 'ja_JP.eucJP',
+		   'ja.UTF-8'			=> 'ja_JP.UTF-8',
+		   'ja_JP.UTF-8'		=> 'ja_JP.UTF-8',
 
 		   'ko'				=> 'ko_KR.eucKR',
 		   'ko_KR'			=> 'ko_KR.eucKR',
 		   'ko_KR.eucKR'		=> 'ko_KR.eucKR',
+		   'ko.UTF-8'			=> 'ko_KR.UTF-8',
+		   'ko_KR.UTF-8'		=> 'ko_KR.UTF-8',
 
 		   'lt'				=> 'lt_LT.ISO8859-13',
 		   'lt_LT'			=> 'lt_LT.ISO8859-13',
 		   'lt_LT.ISO8859-13'		=> 'lt_LT.ISO8859-13',
+		   'lt.UTF-8'			=> 'lt_LT.UTF-8',
+		   'lt_LT.UTF-8'		=> 'lt_LT.UTF-8',
 
 		   'nl'				=> 'nl_NL.ISO8859-1',
 		   'nl_NL'			=> 'nl_NL.ISO8859-1',
 		   'nl_NL.ISO8859-1'		=> 'nl_NL.ISO8859-1',
-
 		   'nl_NL@euro'			=> 'nl_NL.ISO8859-15',
 		   'nl_NL.ISO8859-15'		=> 'nl_NL.ISO8859-15',
 		   'nl_NL.ISO8859-15@euro'	=> 'nl_NL.ISO8859-15',
+		   'nl.UTF-8'			=> 'nl_NL.UTF-8',
+		   'nl_NL.UTF-8'		=> 'nl_NL.UTF-8',
 
 		   'pl'				=> 'pl_PL.ISO8859-2',
 		   'pl_PL'			=> 'pl_PL.ISO8859-2',
 		   'pl_PL.ISO8859-2'		=> 'pl_PL.ISO8859-2',
+		   'pl.UTF-8'			=> 'pl_PL.UTF-8',
+		   'pl_PL.UTF-8'		=> 'pl_PL.UTF-8',
 
-		   'pt'				=> 'pt_PT.ISO8859-1',
 		   'pt_BR'			=> 'pt_BR.ISO8859-1',
 		   'pt_BR.ISO8859-1'		=> 'pt_BR.ISO8859-1',
+		   'pt_BR.UTF-8'		=> 'pt_BR.UTF-8',
 
+		   'pt'				=> 'pt_PT.ISO8859-1',
 		   'pt_PT'			=> 'pt_PT.ISO8859-1',
 		   'pt_PT.ISO8859-1'		=> 'pt_PT.ISO8859-1',
-
 		   'pt_PT@euro'			=> 'pt_PT.ISO8859-15',
 		   'pt_PT.ISO8859-15'		=> 'pt_PT.ISO8859-15',
 		   'pt_PT.ISO8859-15@euro'	=> 'pt_PT.ISO8859-15',
+		   'pt.UTF-8'			=> 'pt_PT.UTF-8',
+		   'pt_PT.UTF-8'		=> 'pt_PT.UTF-8',
 
 		   'ro'				=> 'ro_RO.ISO8859-2',
 		   'ro_RO'			=> 'ro_RO.ISO8859-2',
 		   'ro_RO.ISO8859-2'		=> 'ro_RO.ISO8859-2',
+		   'ro.UTF-8'			=> 'ro_RO.UTF-8',
+		   'ro_RO.UTF-8'		=> 'ro_RO.UTF-8',
 
 		   'ru'				=> 'ru_RU.KOI8-R',
 		   'ru_RU'			=> 'ru_RU.KOI8-R',
 		   'ru_RU.KOI8-R'		=> 'ru_RU.KOI8-R',
+		   'ru.UTF-8'			=> 'ru_RU.UTF-8',
 		   'ru_RU.UTF-8'		=> 'ru_RU.UTF-8',
 
 		   'sk'				=> 'sk_SK.ISO8859-2',
 		   'sk_SK'			=> 'sk_SK.ISO8859-2',
 		   'sk_SK.ISO8859-2'		=> 'sk_SK.ISO8859-2',
+		   'sk.UTF-8'			=> 'sk_SK.UTF-8',
+		   'sk_SK.UTF-8'		=> 'sk_SK.UTF-8',
 
 		   'sl'                         => 'sl_SI.ISO8859-2',
 		   'sl_SI'                      => 'sl_SI.ISO8859-2',
 		   'sl_SI.ISO8859-2'            => 'sl_SI.ISO8859-2',
+		   'sl.UTF-8'			=> 'sl_SI.UTF-8',
+		   'sl.UTF-8'			=> 'sl_SI.UTF-8',
+		   'sl_SI.UTF-8'		=> 'sl_SI.UTF-8',
 
 		   'sv'                         => 'sv_SE.ISO8859-1',
 		   'sv_SE'                      => 'sv_SE.ISO8859-1',
 		   'sv_SE.ISO8859-1'            => 'sv_SE.ISO8859-1',
+		   'sv.UTF-8'			=> 'sv_SE.UTF-8',
+		   'sv_SE.UTF-8'		=> 'sv_SE.UTF-8',
 
 		   'tr'				=> 'tr_TR.ISO8859-9',
 		   'tr_TR'			=> 'tr_TR.ISO8859-9',
 		   'tr_TR.ISO8859-9'		=> 'tr_TR.ISO8859-9',
+		   'tr.UTF-8'			=> 'tr_TR.UTF-8',
+		   'tr_TR.UTF-8'		=> 'tr_TR.UTF-8',
 
 		   'uk'				=> 'uk_UA.UTF-8',
 		   'uk_UA'			=> 'uk_UA.UTF-8',
+		   'uk.UTF-8'			=> 'uk_UA.UTF-8',
 		   'uk_UA.UTF-8'		=> 'uk_UA.UTF-8',
 
 		   'vi'				=> 'vi_VN.UTF-8',
 		   'vi_VN'			=> 'vi_VN.UTF-8',
+		   'vi.UTF-8'			=> 'vi_VN.UTF-8',
 		   'vi_VN.UTF-8'		=> 'vi_VN.UTF-8',
 		   
 		   'zh_CN'			=> 'zh_CN.GB2312',
 		   'zh_CN.GB2312'		=> 'zh_CN.GB2312',
+		   'zh_CN.UTF-8'		=> 'zh_CN.UTF-8',
 
 		   'zh_HK'			=> 'zh_TW.Big5',
 		   'zh_HK.Big5' 		=> 'zh_TW.Big5',
+		   'zh_HK.UTF-8' 		=> 'zh_TW.UTF-8',
 
 		   'zh_TW'			=> 'zh_TW.Big5',
 		   'zh_TW.Big5'			=> 'zh_TW.Big5',
+		   'zh_TW.UTF-8'		=> 'zh_TW.UTF-8',
 
 		   );
 
